#
# spec file for package apache-commons-text
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name text
%global short_name commons-%{base_name}
Name:           apache-%{short_name}
Version:        1.10.0
Release:        2.8
Summary:        A library focused on algorithms working on strings
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://commons.apache.org/proper/commons-text/
Source0:        http://archive.apache.org/dist/commons/text/source/commons-text-%{version}-src.tar.gz
Source1:        %{name}-build.xml
Source2:        http://archive.apache.org/dist/commons/text/source/commons-text-%{version}-src.tar.gz.asc
Source3:        https://www.apache.org/dist/commons/KEYS#/%{name}.keyring
BuildRequires:  ant
BuildRequires:  apache-commons-lang3
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildArch:      noarch

%description
Apache Commons Text is a library focused on algorithms working on strings.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n commons-text-%{version}-src
cp %{SOURCE1} build.xml

%pom_remove_parent
%pom_xpath_inject pom:project "<groupId>org.apache.commons</groupId>"

%build
mkdir -p lib
build-jar-repository -s lib apache-commons-lang3
%{ant} package javadoc

%install
# jars
install -dm 755 %{buildroot}%{_javadir}/%{name}
install -m 0644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{short_name}.jar

# pom
install -dm 755 %{buildroot}%{_mavenpomdir}/%{name}
install -m 0644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{short_name}.pom
%add_maven_depmap %{name}/%{short_name}.pom %{name}/%{short_name}.jar

# javadoc
install -dm 755 %{buildroot}/%{_javadocdir}/%{name}
cp -r target/site/apidocs/* %{buildroot}/%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt NOTICE.txt

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt NOTICE.txt

%changelog
* Mon Oct 31 2022 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and verify source signature
* Fri Oct 14 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.10.0 (mitigation of bsc#1204284,
  CVE-2022-42889)
  * Changes of 1.10.0:
    + Fix CaseUtils when the input string contains only delimiters
    + Add GraalVM test dependencies to fix test failures with Java
    15
    + Incorrect values for Jaccard similarity with empty strings
    + StringSubstitutor map constructor throws NPE on 1.9 with null
    map
    + JaroWinklerDistance returns the same values as
    JaroWinklerSimilarity
    + Correct Javadoc in FileStringLookup
    + Use StringUtils.INDEX_NOT_FOUND constant
    + Remove redundant local variable
    + Replace lambda with method reference
    + Simplify statements
    + Replace statement lambda with expression lambda
    + Use static class inner class in tests
    + Simplify assertion
    + Extract duplicate code
    + Set void return method
    + Remove unused exception from
    TextStringBuilder.readFrom(CharBuffer). This preserves binary
    compatibility but not source compatibility
    + StrBuilder.StrBuilderReader.skip(long): Throw an exception
    when an implicit narrowing conversion in a compound assignment
    would result in information loss or a numeric error such as an
    overflows
    + TextStringBuilder.TextStringBuilderReader.skip(long): Throw
    an exception when an implicit narrowing conversion in a
    compound assignment would result in information loss or a
    numeric error such as an overflows
    + TextStringBuilder.equals whatever the capacity is
    + A More Efficient Implementation for Calculating Size of
    Longest Common Subsequence
    + LookupTranslator returns count of chars consumed, not of
    codepoints consumed
    + Use Math.min() call instead of doing it manually
    + TextStringBuilder: Throw OutOfMemoryError instead of
    NegativeArraySizeException
    + TextStringBuilder: Can't grow to sizes up to
    Integer.MAX_VALUE
    + Make default string lookups configurable via system property
    Remove dns, url, and script lookups from defaults. If these
    lookups are required for use in StringSubstitutor
    .createInterpolator(), they must be enabled via system
    property (bsc#
    + Add DoubleFormat utility
    + Document negative limit for WordUtils abbreviate method
    + Speed up LevenshteinDistance with threshold by exiting early
    + Release Notes page hasn't been updated for 1.9 release yet
    + Add StrBuilder.isNotEmpty()
  * Changes of 1.9:
    + Removed non-existing parameter from Javadocs and spelled out
    parameters in throws
    + StringEscapeUtils.unescapeCsv doesn't remove quotes at begin
    and end of string
    + ScriptStringLookup does not accept ":"
    + StringSubstitutor incorrectly removes some escape characters
    + Make ConstantStringLookup.constantCache final
    + Simplify if in CaseUtils
    + Add StringMatcher.size()
    + Refactor TextStringBuilder.readFrom(Readable), extracting
    readFrom(CharBuffer) and readFrom(Reader)
    + Add BiStringLookup and implementation BiFunctionStringLookup
    + Add org.apache.commons.text.StringSubstitutor
    .StringSubstitutor(StringSubstitutor)
    + Add org.apache.commons.text.TextStringBuilder
    .TextStringBuilder(CharSequence)
    + Add org.apache.commons.text.TextStringBuilder.drainChar(int)
    + Add org.apache.commons.text.TextStringBuilder.drainChars(int,
    int, char[]. int)
    + Add org.apache.commons.text.TextStringBuilder.isNotEmpty()
    + Add org.apache.commons.text.TextStringBuilder.isReallocated()
    + Add org.apache.commons.text.TextStringBuilder.readFrom(Reader,
    int)
    + Add org.apache.commons.text.TextStringBuilder.set(String)
    + Add org.apache.commons.text.TextStringBuilder.wrap(char[])
    + Add org.apache.commons.text.TextStringBuilder.wrap(char[],
    int)
    + Add org.apache.commons.text.io.StringSubstitutorReader
    + Add org.apache.commons.text.lookup.StringLookupFactory
    .functionStringLookup(Function<String, V>)
    + Add org.apache.commons.text.matcher.StringMatcher
    .isMatch(CharSequence, int)
    + Add org.apache.commons.text.matcher.StringMatcher
    .isMatch(CharSequence, int, int, int)
    + Add org.apache.commons.text.matcher.StringMatcherFactory
    .andMatcher(StringMatcher...)
    + Add org.apache.commons.text.matcher.StringMatcherFactory
    .stringMatcher(char...)
* Thu Mar 10 2022 Fridrich Strba <fstrba@suse.com>
- Rewrite build system to build with ant in order to avoid build
  cycles.
  * This package is now the dependency of maven-javadoc-plugin
* Sat Nov  9 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.8
* Tue Jun 25 2019 Ismail Dönmez <idonmez@suse.com>
- Initial release v1.6 on OBS
